select round(q3c_dist(1,2,3,4)::numeric,10);
select round(q3c_dist(null,null,3,4)::numeric,10);
select round(q3c_sindist(1,2,3,4)::numeric,10);
select round(q3c_sindist(null,null,3,4)::numeric,10);
select round(q3c_dist_pm(1,2,3,4,1,2000,1,0,2005)::numeric,10);
select round(q3c_sindist_pm(1,2,3,4,1,2000,1,0,2005)::numeric,10);
select round(q3c_dist_pm(1,2,3,4,1,2000,null,0,2005)::numeric,10);
select round(q3c_sindist_pm(1,2,3,4,1,2000,null,0,2005)::numeric,10);
select round(q3c_dist_pm(1,2,3,null,1,2000,0,0,2005)::numeric,10);
select round(q3c_sindist_pm(1,2,3,null,1,2000,0,0,2005)::numeric,10);
