\echo Use "ALTER EXTENSION q3c UPDATE TO '2.0.3'" to load this file. \quit

-- No SQL objects changed in 2.0.3. The release updates the C implementation
-- to validate internal iteration arguments before indexing cached arrays.
